==> phpwiki_1.3.7.orig.tar.gz: phpwiki-1.3.7/locale/nl/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%s: %s"] =
   "%s: %s";
$locale["(diff)"] =
   "(diff)";
$locale["- saved to database as version %d"] =
   "- bewaard in de data base als versie %d";
$locale["BackLinks"] =
   "TerugLinks";
$locale["Cancel"] =
   "Annuleer";
$locale["Complete."] =
   "Klaar.";
$locale["Describe %s here."] =
   "Beschrijf %s hier.";
$locale["Diff"] =
   "Diff";
$locale["Edit"] =
   "Verander";
$locale["Edit %s"] =
   "Verander %s";
$locale["Edit: %s"] =
   "Verander: %s";
$locale["EditText"] =
   "VeranderTekst";
$locale["Fatal PhpWiki Error"] =
   "PhpWiki Fatale Fout";
$locale["FindPage"] =
   "ZoekPagina";
$locale["Full text search results for '%s'"] =
   "Volledige tekst zoek resultaten naar '%s'";
$locale["FullTextSearch"] =
   "VolledigeTekstZoek";
$locale["GoodStyle"] =
   "GoedeStijl";
$locale["H"] =
   "H";
$locale["Height"] =
   "Hoogte";
$locale["Hits"] =
   "Teller";
$locale["Hits:"] =
   "Teller:";
$locale["HomePage"] =
   "ThuisPagina";
$locale["Include of '%s' failed"] =
   "Insert van '%s' gefaald";
$locale["Last Author"] =
   "Vorige Auteur";
$locale["Last edited on %s."] =
   "Meest recente verandering op %s.";
$locale["Loading up virgin wiki"] =
   "Laden van maagdelijke wiki";
$locale["Lock Page"] =
   "Open Pagina";
$locale["Locked"] =
   "Lst";
$locale["MIME file %s"] =
   "MIME bestand %";
$locale["MostPopular"] =
   "Meestbezochte";
$locale["New page."] =
   "Nieuw pagina.";
$locale["Next"] =
   "Volgende";
$locale["None"] =
   "Geen";
$locale["Page Locked"] =
   "Sidan r Lst";
$locale["Page Name"] =
   "Pagina Naam";
$locale["PageHistory"] =
   "PaginaGeschiedenis";
$locale["Preview"] =
   "Voorvertonig";
$locale["Previous"] =
   "Vorige";
$locale["Previous Author"] =
   "Vorige Auteur";
$locale["Printer"] =
   "Drukker";
$locale["RecentChanges"] =
   "RecenteVeranderingen";
$locale["References"] =
   "Referenties";
$locale["Remove Page"] =
   "Verwijder Pagina";
$locale["Remove page"] =
   "Verwijder pagina";
$locale["Removed page '%s' succesfully."] =
   "Pagina '%s' verwijderd.";
$locale["Return to %s"] =
   "Terug naar %s";
$locale["Save"] =
   "Bewaar";
$locale["Saved: %s"] =
   "Bewaard: %s";
$locale["Search"] =
   "Zoek";
$locale["See %s"] =
   "Zie %s";
$locale["See %s tips for editing."] =
   "%s tips for veranderen.";
$locale["Serialized file %s"] =
   "Geserialiseerd bestand %s";
$locale["Skipping"] =
   "Overgeslagen";
$locale["Sorry for the inconvenience."] =
   "Excuses voor het ongemak.";
$locale["TextFormattingRules"] =
   "TekstFormatteringsRegels";
$locale["Thank you for editing %s."] =
   "Bedankt voor het veranderen van %s.";
$locale["The %d most popular pages of this wiki:"] =
   "De %d meestbezochte pagina's van deze Wiki:";
$locale["The %d most recent %s are listed below."] =
   "De %d meest recent %s staan hieronder.";
$locale["The PhpWiki Programming Team"] =
   "Het PhpWiki programmeerteam";
$locale["The PhpWiki programming team"] =
   "Het PhpWiki programmeerteam";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Deze pagina is afgesloten door de beheerder en kan niet veranderd worden.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["Title Search"] =
   "Titel Zoek";
$locale["Title search results for '%s'"] =
   "Titel zoek resultaten naar '%s'";
$locale["TitleSearch"] =
   "TitelZoek";
$locale["Unlock Page"] =
   "Sluit Pagina Af";
$locale["Update Preferences"] =
   "Zet Voorkeuren";
$locale["UserPreferences"] =
   "GebruikersVoorkeuren";
$locale["Version"] =
   "Versie";
$locale["Version %d"] =
   "Versie %d";
$locale["Version %s, saved %s."] =
   "Versie %s, bewarrd %s.";
$locale["Version %s, saved on %s."] =
   "Versie %s, bewarrd op %s.";
$locale["Versions are identical"] =
   "Versies zijn identiek";
$locale["View Source"] =
   "Bron Tekst";
$locale["View Source: %s"] =
   "Bron tekst: %s";
$locale["W"] =
   "B";
$locale["Width"] =
   "Breedte";
$locale["You are about to remove '%s' permanently!"] =
   "Je staat op het punt '%s' voorgoed te verwijderen!";
$locale["You are signed in as %s"] =
   "Je bent ingelogd als %s";
$locale["You must specify a directory to dump to"] =
   "Je moet een directory specificeren om in te storten";
$locale["Your careful attention to detail is much appreciated."] =
   "Je zorgvuldige aandacht voor detail wordt erg gewaardeerd.";
$locale["[%d] See [%s]"] =
   "[%d] Zie [%s]";
$locale["by %s"] =
   "door %s";
$locale["current version"] =
   "huidige versie";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "van %s";
$locale["is identical to current version %d - skipped"] =
   "is gelijk aaan huidige versie %d - overgeslagen";
$locale["locked"] =
   "lst";
$locale["new page"] =
   "nieuw pagina";
$locale["plain file %s"] =
   "plat bestand %";
$locale["saved as %s"] =
   "bewaard als %s";
$locale["version %d"] =
   "versie %d";
$locale["version %s"] =
   "versie %s";

?>

==> phpwiki_1.3.12p3.orig.tar.gz: phpwiki-1.3.12p3/locale/nl/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%s: %s"] =
   "%s: %s";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "Kopier je veranderingen naar het klipbord of een andere tijdelijke plaats (bijv. een tekst editor).";
$locale["(diff)"] =
   "(diff)";
$locale["- saved to database as version %d"] =
   "- bewaard in de data base als versie %d";
$locale["An unnamed PhpWiki"] =
   "Naamloos PhpWiki";
$locale["BackLinks"] =
   "TerugLinks";
$locale["Cancel"] =
   "Annuleer";
$locale["Complete."] =
   "Klaar.";
$locale["Couldn't connect to %s"] =
   "Kan verbinding naar data base %s niet tot stand brengen, geef op.";
$locale["Describe %s here."] =
   "Beschrijf %s hier.";
$locale["Diff"] =
   "Diff";
$locale["Diff: %s"] =
   "Diff van: %s";
$locale["Edit"] =
   "Verander";
$locale["Edit %s"] =
   "Verander %s";
$locale["Edit: %s"] =
   "Verander: %s";
$locale["EditText"] =
   "VeranderTekst";
$locale["Edited by: %s"] =
   "Verander von: %s";
$locale["Fatal PhpWiki Error"] =
   "PhpWiki Fatale Fout";
$locale["FindPage"] =
   "ZoekPagina";
$locale["Full text search results for '%s'"] =
   "Volledige tekst zoek resultaten naar '%s'";
$locale["FullTextSearch"] =
   "VolledigeTekstZoek";
$locale["GoodStyle"] =
   "GoedeStijl";
$locale["H"] =
   "H";
$locale["Height"] =
   "Hoogte";
$locale["Hits"] =
   "Teller";
$locale["Hits:"] =
   "Teller:";
$locale["Home"] =
   "Thuis";
$locale["HomePage"] =
   "ThuisPagina";
$locale["Include of '%s' failed."] =
   "Insert van '%s' gefaald.";
$locale["Last Author"] =
   "Vorige Auteur";
$locale["Last Modified"] =
   "meest recente verandering";
$locale["Last edited %s"] =
   "Meest recente verandering %s";
$locale["Last edited on %s"] =
   "Meest recente verandering op %s";
$locale["LdapSearch"] =
   "LdapZoek";
$locale["Links"] =
   "Links";
$locale["LiveSearch"] =
   "LiveZoek";
$locale["Loading up virgin wiki"] =
   "Laden van maagdelijke wiki";
$locale["Lock Page"] =
   "Open Pagina";
$locale["Locked"] =
   "Lst";
$locale["MIME file %s"] =
   "MIME bestand %s";
$locale["MostPopular"] =
   "Meestbezochte";
$locale["New page"] =
   "Nieuw pagina";
$locale["Newer page:"] =
   "Nieuw pagina:";
$locale["Next"] =
   "Volgende";
$locale["None"] =
   "Geen";
$locale["OldTextFormattingRules"] =
   "OudTekstFormatteringsRegels";
$locale["Page Locked"] =
   "Sidan r Lst";
$locale["Page Name"] =
   "Pagina Naam";
$locale["Page removed %s"] =
   "Verwijder %s";
$locale["PageHistory"] =
   "PaginaGeschiedenis";
$locale["PhpWikiAdministration"] =
   "PhpWikiBeheer";
$locale["PhpWikiAdministration/Chmod"] =
   "PhpWikiBeheer/Chmod";
$locale["PhpWikiAdministration/Replace"] =
   "PhpWikiBeheer/Vervangt";
$locale["PhpWikiDocumentation"] =
   "PhpWikiDocumentatie";
$locale["Preview"] =
   "Voorvertonig";
$locale["Previous"] =
   "Vorige";
$locale["Previous Author"] =
   "Vorige Auteur";
$locale["Printer"] =
   "Drukker";
$locale["RecentChanges"] =
   "RecenteVeranderingen";
$locale["RecentVisitors"] =
   "RecenteBezoekers";
$locale["References"] =
   "Referenties";
$locale["ReleaseNotes"] =
   "UitgaveNoten";
$locale["Remove Page"] =
   "Verwijder Pagina";
$locale["Removed by: %s"] =
   "Verwijder von: %s";
$locale["Removed page '%s' successfully."] =
   "Pagina '%s' verwijderd.";
$locale["Return to %s"] =
   "Terug naar %s";
$locale["Save"] =
   "Bewaar";
$locale["Saved: %s"] =
   "Bewaard: %s";
$locale["Search"] =
   "Zoek";
$locale["Search & Replace"] =
   "Zoek & Vervangt";
$locale["See %s"] =
   "Zie %s";
$locale["See %s tips for editing."] =
   "%s tips for veranderen.";
$locale["Serialized file %s"] =
   "Geserialiseerd bestand %s";
$locale["Skipping"] =
   "Overgeslagen";
$locale["Sorry for the inconvenience."] =
   "Excuses voor het ongemak.";
$locale["TextFormattingRules"] =
   "TekstFormatteringsRegels";
$locale["Thank you for editing %s."] =
   "Bedankt voor het veranderen van %s.";
$locale["The %d most popular pages of this wiki:"] =
   "De %d meestbezochte pagina's van deze Wiki:";
$locale["The %d most recent %s are listed below."] =
   "De %d meest recent %s staan hieronder.";
$locale["The PhpWiki programming team"] =
   "Het PhpWiki programmeerteam";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Deze pagina is afgesloten door de beheerder en kan niet veranderd worden.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["Title Search"] =
   "Titel Zoek";
$locale["Title search results for '%s'"] =
   "Titel zoek resultaten naar '%s'";
$locale["TitleSearch"] =
   "TitelZoek";
$locale["Unlock Page"] =
   "Sluit Pagina Af";
$locale["Update Preferences"] =
   "Zet Voorkeuren";
$locale["UserPreferences"] =
   "GebruikersVoorkeuren";
$locale["Version"] =
   "Versie";
$locale["Version %d"] =
   "Versie %d";
$locale["Version %s, saved %s"] =
   "Versie %s, bewarrd %s";
$locale["Version %s, saved on %s"] =
   "Versie %s, bewarrd op %s";
$locale["Versions are identical"] =
   "Versies zijn identiek";
$locale["View Source"] =
   "Bron Tekst";
$locale["View Source: %s"] =
   "Bron tekst: %s";
$locale["W"] =
   "B";
$locale["Width"] =
   "Breedte";
$locale["You are about to remove '%s'!"] =
   "Je staat te verwijderen '%s' op het punt!";
$locale["You must specify a directory to dump to"] =
   "Je moet een directory specificeren om in te storten";
$locale["Your careful attention to detail is much appreciated."] =
   "Je zorgvuldige aandacht voor detail wordt erg gewaardeerd.";
$locale["Your home page has not been created yet so your preferences cannot not be saved."] =
   "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["[%d] See [%s]"] =
   "[%d] Zie [%s]";
$locale["by %s"] =
   "door %s";
$locale["current version"] =
   "huidige versie";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "van %s";
$locale["locked"] =
   "lst";
$locale["plain file %s"] =
   "plat bestand %s";
$locale["saved as %s"] =
   "bewaard als %s";
$locale["version %d"] =
   "versie %d";
$locale["version %s"] =
   "versie %s";
$locale["version <em>%s</em>"] =
   "versie <em>%s</em>";

?>
